<?php
/**  
 * @package SCREENREADER::plugins::system
 * @subpackage libraries
 * @subpackage fields
 * @author Joomla! Extensions Store
 * @copyright (C) 2014 - Joomla! Extensions Store
 * @license GNU/GPLv2 http://www.gnu.org/licenses/gpl-2.0.html   
 */ 
defined( '_JEXEC' ) or die( 'Restricted access' );
jimport('joomla.form.fields.list');

/**
 * Form Field for menu tree
 * @package SCREENREADER::plugins::system
 * @subpackage libraries 
 * @subpackage fields
 * @since 2.4
 */
class JFormFieldMenuMultiselect extends JFormFieldList {
	/**
	 * Tree recursion menu
	 * 
	 * @access private 
	 * @param int $id
	 * @param string $indent
	 * @param array $list
	 * @param array $children
	 * @param int $maxlevel
	 * @param int $level
	 * @param int $type
	 * @return array
	 */
	private static function treeRecurse($id, $indent, $list, &$children, $maxlevel = 9999, $level = 0, $type = 1) {
		if (@$children [$id] && $level <= $maxlevel) {
			foreach ( $children [$id] as $v ) {
				$id = $v->id;
	
				if ($type) {
					$pre = '<sup>|_</sup>&nbsp;';
					$spacer = '.&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
				} else {
					$pre = '- ';
					$spacer = '&nbsp;&nbsp;';
				}
	
				if ($v->parent == 0) {
					$txt = $v->name;
				} else {
					$txt = $pre . $v->name;
				}
				$pt = $v->parent;
				$list [$id] = $v;
				$list [$id]->treename = "$indent$txt";
				$list [$id]->children = @count ( $children [$id] );
				$list = self::TreeRecurse ( $id, $indent . $spacer, $list, $children, $maxlevel, $level + 1, $type );
			}
		}
		return $list;
	}
	
	/**
	 * Build the multiple select list for Menu Links/Pages
	 * 
	 * @access public
	 * @return array
	 */
	protected function getOptions() {
		$db = JFactory::getDBO ();
		
		// get a list of the menu items
		$query = 'SELECT m.id, m.parent_id AS parent, m.title AS name, m.menutype, t.title' .
				' FROM #__menu AS m' .
				' INNER JOIN #__menu_types AS t' .
				' ON m.menutype = t.menutype' .
				' WHERE m.published = 1' .
				' AND m.client_id = 0' .
				' ORDER BY m.menutype, m.parent_id, m.lft';
		$db->setQuery ( $query );
		$mitems = $db->loadObjectList ();
		$mitems_temp = $mitems;
		
		if(empty($mitems)) {
			return $mitems;
		}
		
		// establish the hierarchy of the menu
		$children = array ();
		// first pass - collect children
		foreach ( $mitems as $v ) {
			$id = $v->id;
			$pt = $v->parent;
			$list = @$children [$pt] ? $children [$pt] : array ();
			array_push ( $list, $v );
			$children [$pt] = $list;
		}
		// second pass - get an indent list of the items
		$list = self::treeRecurse ( intval ( $mitems [0]->parent ), '', array (), $children, 9999, 0, 0 );
		
		// Code that adds menu name to Display of Page(s)
		$mitems_spacer = $mitems_temp [0]->menutype;
		
		$mitems = array ();
		$lastMenuType = null;
		$tmpMenuType = null;
		foreach ( $list as $list_a ) {
			if ($list_a->menutype != $lastMenuType) {
				if ($tmpMenuType) {
					$mitems [] = JHtml::_ ( 'select.option', '</OPTGROUP>' );
				}
				$mitems [] = JHtml::_ ( 'select.option', '<OPTGROUP>', $list_a->title );
				$lastMenuType = $list_a->menutype;
				$tmpMenuType = $list_a->menutype;
			}
			
			$mitems [] = JHtml::_ ( 'select.option', $list_a->id, $list_a->treename );
		}
		if ($lastMenuType !== null) {
			$mitems [] = JHtml::_ ( 'select.option', '</OPTGROUP>' );
		}
		
		if (version_compare ( JVERSION, '3.0', '<=' )) {
			$noActiveOption = JHtml::_('select.option', '0', JText::_('SCR_NOEXCLUSION'));
			array_unshift($mitems, $noActiveOption);
		}
		
		return $mitems;
	}
	
	/**
	 * Method to get the field label markup.
	 *
	 * @return  string  The field label markup.
	 *
	 * @since   11.1
	 */
	protected function getLabel()
	{
		if(version_compare(JVERSION, '3', '>=')) {
			// Add custom JS to rework bootstrap popovers for the label description
			$doc = JFactory::getDocument();
			// Include Bootstrap framework
			JHtml::_('bootstrap.framework');
			$popoverTitle = JText::_('SCR_SUPPORTED_LANGUAGES_BY_ENGINE', true);
			$script = <<<EOL
			jQuery(function($){
				var engineLanguagesMapping = {
					'proxy_responsive' : 'Afrikaans, Albanian, Arabic, Armenian, Bosnian, Brazilian Portuguese, Catalan, Chinese, Croatian, Czech, Danish, Dutch, English, Esperanto, French, Finnish, German, Greek, Hindi, Hungarian, Icelandic, Indonesian, Italian, Japanese, Korean, Latvian, Macedonian, Norwegian, Portuguese, Polish, Romanian, Russian, Serbian, Slovak, Spanish, Swedish, Swahili, Tamil, Thai, Turkish, Vietnamese, Welsh',
					'proxy' : 'Afrikaans, Albanian, Arabic, Armenian, Bosnian, Brazilian Portuguese, Catalan, Chinese, Croatian, Czech, Danish, Dutch, English, Esperanto, French, Finnish, German, Greek, Hindi, Hungarian, Icelandic, Indonesian, Italian, Japanese, Korean, Latvian, Macedonian, Norwegian, Portuguese, Polish, Romanian, Russian, Serbian, Slovak, Spanish, Swedish, Swahili, Tamil, Thai, Turkish, Ukraninan, Vietnamese, Welsh',
					'proxy_virtual_free' : 'Arabic, Brazilian Portuguese, Catalan, Czech, Danish, Dutch, English, Faroese, French, Finnish, German, Greek, Italian, Japanese, Korean, Norwegian, Portuguese, Polish, Russian, Spanish, Swedish, Turkish',
					'proxy_ispeech' : 'Brazilian Portuguese, Catalan, Chinese, Danish, Dutch, English, French, Finnish, German, Italian, Japanese, Korean, Norwegian, Portuguese, Polish, Russian, Spanish, Swedish',
					'proxy_inforobo' : 'Arabic, Armenian, Brazilian Portuguese, Chinese, Croatian, Czech, Danish, Dutch, English, French, Finnish, German, Greek, Hindi, Hungarian, Indonesian, Italian, Japanese, Korean, Norwegian, Portuguese, Polish, Romanian, Russian, Slovak, Spanish, Swedish, Turkish, Vietnamese, Welsh',
					'proxy_texttomp3' : 'Brazilian Portuguese, English, French, German, Italian, Japanese, Portuguese, Spanish',
					'proxy_ttsmp3' : 'Arabic, Brazilian Portuguese, Chinese, Danish, Dutch, English, French, German, Italian, Japanese, Korean, Norwegian, Portuguese, Polish, Russian, Spanish, Swedish, Turkish, Welsh'
				};
			
				var popoverTimeout;
				var targetEngineDropdown = $('#jform_params_reader_engine');
				var targetEngineDropdownPlaceholder = $('#jform_params_reader_engine_chzn');
				$(document).on('click', '#jform_params_reader_engine_chzn', function(){
					showLanguagesPopover(targetEngineDropdown);
				});
				var showLanguagesPopover = function(element) {
					var dropdownValue = $(element).val();
					if(typeof(popoverTimeout) !== 'undefined') {
						clearTimeout(popoverTimeout);
					}
					targetEngineDropdownPlaceholder.popover('destroy').popover({trigger:'manual'});
					targetEngineDropdownPlaceholder.attr('data-content', engineLanguagesMapping[dropdownValue]);
					targetEngineDropdownPlaceholder.attr('data-original-title', '$popoverTitle');
					targetEngineDropdownPlaceholder.popover('show');
					popoverTimeout = setTimeout(function(){
						targetEngineDropdownPlaceholder.popover('hide');
					}, 5000);
				}
			});
EOL;
			$doc->addScriptDeclaration($script);
		}
		
		return parent::getLabel();
	}
}